@@ -1,14 +1,11 @@
-# pylint: disable=invalid-name,missing-docstring
+# pylint: disable=invalid-name,missing-docstring,redefined-builtin
 
 extensions = [
     "sphinx.ext.extlinks",
     "sphinx.ext.napoleon",
     "sphinx.ext.autodoc",
     "sphinx.ext.intersphinx",
-    "sphinx_autodoc_typehints",
 ]
-source_suffix = ".rst"
-master_doc = "index"
 intersphinx_mapping = {"python": ("https://docs.python.org/3", None)}
 
 # General information about the project.
@@ -16,15 +13,15 @@ project = "Fava"
 copyright = "2016, Dominik Aumayr"
 author = "Dominik Aumayr"
 
-exclude_patterns = ["_build"]
-pygments_style = "sphinx"
-
 extlinks = {
     "bug": ("https://github.com/beancount/fava/issues/%s", "#"),
     "user": ("https://github.com/%s", "@"),
 }
 
-autodoc_default_flags = ["members", "undoc-members"]
+autodoc_default_options = {
+    "members": True,
+    "undoc-members": True,
+}
 
 
 def skip_namedtuples(_app, _what, _name, obj, _options, _lines):
@@ -37,6 +34,7 @@ def setup(app):
     app.connect("autodoc-skip-member", skip_namedtuples)
 
 
+desc = 'Web interface for <a href="http://furius.ca/beancount/">Beancount</a>'
 # Options for HTML output
 html_theme = "alabaster"
 html_static_path = ["static"]
@@ -44,7 +42,7 @@ html_theme_options = {
     "logo": "logo.png",
     "logo_name": True,
     "logo_text_align": "center",
-    "description": 'Web interface for <a href="http://furius.ca/beancount/">Beancount</a>',
+    "description": desc,
     "github_user": "beancount",
     "github_repo": "fava",
     "github_button": "false",
