@@ -1,14 +1,11 @@
-# pylint: disable=missing-docstring
-
+"""Fava's budget syntax."""
 from datetime import date
 
 from beancount.core.number import D
 
-from fava.core.budgets import (
-    parse_budgets,
-    calculate_budget,
-    calculate_budget_children,
-)
+from fava.core.budgets import calculate_budget
+from fava.core.budgets import calculate_budget_children
+from fava.core.budgets import parse_budgets
 
 
 def test_budgets(load_doc):
@@ -23,12 +20,10 @@ def test_budgets(load_doc):
 
     assert len(errors) == 2
 
-    assert (
-        calculate_budget(
-            budgets, "Expenses", date(2016, 6, 1), date(2016, 6, 8)
-        )
-        == {}
+    empty = calculate_budget(
+        budgets, "Expenses", date(2016, 6, 1), date(2016, 6, 8)
     )
+    assert empty == {}
 
     budgets = calculate_budget(
         budgets, "Expenses:Groceries", date(2016, 6, 1), date(2016, 6, 8)
@@ -144,9 +139,12 @@ def test_budgets_children(budgets_doc):
         budgets_doc, "Expenses:Books", date(2017, 1, 1), date(2017, 1, 2)
     )["USD"] == D("12.00")
 
-    assert calculate_budget_children(
-        budgets_doc,
-        "Expenses:Books:Notebooks",
-        date(2017, 1, 1),
-        date(2017, 1, 2),
-    )["USD"] == D("2.00")
+    assert (
+        calculate_budget_children(
+            budgets_doc,
+            "Expenses:Books:Notebooks",
+            date(2017, 1, 1),
+            date(2017, 1, 2),
+        )["USD"]
+        == D("2.00")
+    )
