@@ -1,5 +1,4 @@
 # pylint: disable=missing-docstring
-
 from beancount.core.number import D
 
 
@@ -13,7 +12,6 @@ def test_format_decimal(example_ledger):
 
 def test_format_decimal_locale(example_ledger):
     fmt = example_ledger.format_decimal
-    old_locale = example_ledger.fava_options["locale"]
     example_ledger.fava_options["locale"] = "en_IN"
     fmt.load_file()
     assert fmt(D("1111111.333"), "USD") == "11,11,111.33"
@@ -25,5 +23,4 @@ def test_format_decimal_locale(example_ledger):
     example_ledger.fava_options["locale"] = "invalid"
     fmt.load_file()
     assert fmt(D("1111111.333"), "USD") == "1111111.33"
-    example_ledger.fava_options["locale"] = old_locale
     fmt.load_file()
