@@ -1,33 +1,49 @@
 # pylint: disable=missing-docstring
-
-
 import hashlib
 from io import BytesIO
-import os
+from pathlib import Path
+from typing import Any
+from typing import Optional
 
 import flask
 import pytest
 
+from fava.core.charts import dumps
 from fava.core.misc import align
 
 
-def test_api_changed(app, test_client):
-    with app.test_request_context():
+def assert_api_error(response, msg: Optional[str] = None) -> None:
+    """Asserts that the response errored and contains the message."""
+    assert response.status_code == 200
+    assert not response.json["success"]
+    if msg:
+        assert msg in response.json["error"]
+
+
+def assert_api_success(response, data: Optional[Any] = None) -> None:
+    """Asserts that the request was successful and contains the data."""
+    assert response.status_code == 200
+    assert response.json["success"]
+    if data:
+        assert data == response.json["data"]
+
+
+def test_api_changed(app, test_client) -> None:
+    with app.test_request_context("/long-example/"):
         app.preprocess_request()
         url = flask.url_for("json_api.changed")
 
-    result = test_client.get(url)
-    response_data = flask.json.loads(result.get_data(True))
-    assert response_data == {"data": False, "success": True}
+    response = test_client.get(url)
+    assert_api_success(response, False)
 
 
-def test_api_add_document(app, test_client, tmpdir):
-    with app.test_request_context():
+def test_api_add_document(app, test_client, tmp_path) -> None:
+    with app.test_request_context("/long-example/"):
         app.preprocess_request()
         old_documents = flask.g.ledger.options["documents"]
-        flask.g.ledger.options["documents"] = [str(tmpdir)]
+        flask.g.ledger.options["documents"] = [str(tmp_path)]
         request_data = {
-            "folder": str(tmpdir),
+            "folder": str(tmp_path),
             "account": "Expenses:Food:Restaurant",
             "file": (BytesIO(b"asdfasdf"), "2015-12-12 test"),
         }
@@ -36,49 +52,64 @@ def test_api_add_document(app, test_client, tmpdir):
         response = test_client.put(url)
         assert response.status_code == 400
 
-        filename = os.path.join(
-            str(tmpdir), "Expenses", "Food", "Restaurant", "2015-12-12 test"
+        filename = (
+            tmp_path / "Expenses" / "Food" / "Restaurant" / "2015-12-12 test"
         )
 
         response = test_client.put(url, data=request_data)
-        print(flask.json.loads(response.get_data(True)))
-        assert flask.json.loads(response.get_data(True)) == {
-            "success": True,
-            "data": "Uploaded to {}".format(filename),
-        }
-        assert os.path.isfile(filename)
+        assert_api_success(response, f"Uploaded to {filename}")
+        assert Path(filename).is_file()
 
         request_data["file"] = (BytesIO(b"asdfasdf"), "2015-12-12 test")
         response = test_client.put(url, data=request_data)
-        assert flask.json.loads(response.get_data(True)) == {
-            "success": False,
-            "error": "{} already exists.".format(filename),
-        }
+        assert_api_error(response, f"{filename} already exists.")
         flask.g.ledger.options["documents"] = old_documents
 
 
-def test_api_source_put(app, test_client):
-    with app.test_request_context():
+def test_api_errors(app, test_client) -> None:
+    with app.test_request_context("/long-example/"):
+        app.preprocess_request()
+        url = flask.url_for("json_api.errors")
+
+    response = test_client.get(url)
+    assert_api_success(response, 0)
+
+
+def test_api_payee_accounts(app, test_client) -> None:
+    with app.test_request_context("/long-example/"):
+        app.preprocess_request()
+        url = flask.url_for("json_api.payee_accounts", payee="test")
+
+    response = test_client.get(url)
+    assert_api_success(response, [])
+
+
+def test_api_move(app, test_client) -> None:
+    with app.test_request_context("/long-example/"):
+        app.preprocess_request()
+        url = flask.url_for("json_api.move")
+
+    response = test_client.get(url)
+    assert_api_error(response)
+
+
+def test_api_source_put(app, test_client) -> None:
+    with app.test_request_context("/long-example/"):
         app.preprocess_request()
         url = flask.url_for("json_api.source")
+        path = flask.g.ledger.beancount_file_path
 
     # test bad request
     response = test_client.put(url)
-    response_data = flask.json.loads(response.get_data(True))
-    assert response_data == {
-        "error": "Invalid JSON request.",
-        "success": False,
-    }
-    assert response.status_code == 200
+    assert_api_error(response, "Invalid JSON request.")
 
-    path = app.config["BEANCOUNT_FILES"][0]
     payload = open(path, encoding="utf-8").read()
     sha256sum = hashlib.sha256(open(path, mode="rb").read()).hexdigest()
 
     # change source
-    result = test_client.put(
+    response = test_client.put(
         url,
-        data=flask.json.dumps(
+        data=dumps(
             {
                 "source": "asdf" + payload,
                 "sha256sum": sha256sum,
@@ -87,10 +118,8 @@ def test_api_source_put(app, test_client):
         ),
         content_type="application/json",
     )
-    assert result.status_code == 200
-    response_data = flask.json.loads(result.get_data(True))
     sha256sum = hashlib.sha256(open(path, mode="rb").read()).hexdigest()
-    assert response_data == {"success": True, "data": sha256sum}
+    assert_api_success(response, sha256sum)
 
     # check if the file has been written
     assert open(path, encoding="utf-8").read() == "asdf" + payload
@@ -98,7 +127,7 @@ def test_api_source_put(app, test_client):
     # write original source file
     result = test_client.put(
         url,
-        data=flask.json.dumps(
+        data=dumps(
             {"source": payload, "sha256sum": sha256sum, "file_path": path}
         ),
         content_type="application/json",
@@ -107,52 +136,47 @@ def test_api_source_put(app, test_client):
     assert open(path, encoding="utf-8").read() == payload
 
 
-def test_api_format_source(app, test_client):
-    with app.test_request_context():
+def test_api_format_source(app, test_client) -> None:
+    with app.test_request_context("/long-example/"):
         app.preprocess_request()
         url = flask.url_for("json_api.format_source")
+        path = flask.g.ledger.beancount_file_path
 
-    path = app.config["BEANCOUNT_FILES"][0]
     payload = open(path, encoding="utf-8").read()
 
-    result = test_client.put(
+    response = test_client.put(
         url,
-        data=flask.json.dumps({"source": payload}),
+        data=dumps({"source": payload}),
         content_type="application/json",
     )
-    data = flask.json.loads(result.get_data(True))
-    assert data == {"data": align(payload, {}), "success": True}
+    assert_api_success(response, align(payload, 61))
 
 
-def test_api_format_source_options(app, test_client):
-    # pylint: disable=too-many-function-args
-    path = app.config["BEANCOUNT_FILES"][0]
-    payload = open(path, encoding="utf-8").read()
-    with app.test_request_context():
+def test_api_format_source_options(app, test_client) -> None:
+    with app.test_request_context("/long-example/"):
         app.preprocess_request()
+        path = flask.g.ledger.beancount_file_path
+        payload = open(path, encoding="utf-8").read()
+
         url = flask.url_for("json_api.format_source")
         old_currency_column = flask.g.ledger.fava_options["currency-column"]
         flask.g.ledger.fava_options["currency-column"] = 90
 
-        result = test_client.put(
+        response = test_client.put(
             url,
-            data=flask.json.dumps({"source": payload}),
+            data=dumps({"source": payload}),
             content_type="application/json",
         )
-        data = flask.json.loads(result.get_data(True))
-        assert data == {
-            "data": align(payload, {"currency-column": 90}),
-            "success": True,
-        }
+        assert_api_success(response, align(payload, 90))
 
         flask.g.ledger.fava_options["currency-column"] = old_currency_column
 
 
-def test_api_add_entries(app, test_client, tmpdir):
-    with app.test_request_context():
+def test_api_add_entries(app, test_client, tmp_path):
+    with app.test_request_context("/long-example/"):
         app.preprocess_request()
         old_beancount_file = flask.g.ledger.beancount_file_path
-        test_file = tmpdir.join("test_file")
+        test_file = tmp_path / "test_file"
         test_file.open("a")
         flask.g.ledger.beancount_file_path = str(test_file)
 
@@ -208,16 +232,14 @@ def test_api_add_entries(app, test_client, tmpdir):
         url = flask.url_for("json_api.add_entries")
 
         response = test_client.put(
-            url, data=flask.json.dumps(data), content_type="application/json"
+            url, data=dumps(data), content_type="application/json"
         )
-        assert flask.json.loads(response.get_data(True)) == {
-            "success": True,
-            "data": "Stored 3 entries.",
-        }
+        assert_api_success(response, "Stored 3 entries.")
 
         assert (
             test_file.read_text("utf-8")
-            == """2017-01-12 * "Test1" ""
+            == """
+2017-01-12 * "Test1" ""
   Assets:US:ETrade:Cash                                 100 USD
   Assets:US:ETrade:GLD
 
@@ -228,7 +250,6 @@ def test_api_add_entries(app, test_client, tmpdir):
 2017-12-12 * "Test3" ""
   Assets:US:ETrade:Cash                                 100 USD
   Assets:US:ETrade:GLD
-
 """
         )
 
@@ -243,11 +264,11 @@ def test_api_add_entries(app, test_client, tmpdir):
         ("select sum(day)", "43558"),
     ],
 )
-def test_api_query_result(query_string, result_str, app, test_client):
-    with app.test_request_context():
+def test_api_query_result(query_string, result_str, app, test_client) -> None:
+    with app.test_request_context("/long-example/"):
         app.preprocess_request()
         url = flask.url_for("json_api.query_result", query_string=query_string)
 
-    result = test_client.get(url)
-    assert result.status_code == 200
-    assert result_str in result.get_data(True)
+    response = test_client.get(url)
+    assert response.status_code == 200
+    assert result_str in response.get_data(True)
