@@ -1,18 +1,20 @@
 # pylint: disable=missing-docstring
-
 from werkzeug.test import Client
 from werkzeug.wrappers import BaseResponse
 
-from fava.util import simple_wsgi, slugify, pairwise, listify, send_file_inline
-
 from .conftest import data_file
+from fava.util import listify
+from fava.util import next_key
+from fava.util import pairwise
+from fava.util import send_file_inline
+from fava.util import simple_wsgi
+from fava.util import slugify
 
 
 def test_listify():
     @listify
     def fun():
-        for i in [1, 2, 3]:
-            yield i
+        yield from [1, 2, 3]
 
     assert fun() == [1, 2, 3]
 
@@ -29,6 +31,16 @@ def test_simple_wsgi():
     assert resp.data == b""
 
 
+def test_next_key() -> None:
+    assert next_key("statement", {}) == "statement"
+    assert next_key("statement", {"foo": 1}) == "statement"
+    assert next_key("statement", {"foo": 1, "statement": 1}) == "statement-2"
+    assert (
+        next_key("statement", {"statement": 1, "statement-2": 1})
+        == "statement-3"
+    )
+
+
 def test_slugify():
     assert slugify("Example Beancount File") == "example-beancount-file"
     assert slugify("    Example Beancount File  ") == "example-beancount-file"
@@ -43,7 +55,6 @@ def test_slugify():
 
 def test_send_file_inline(app):
     with app.test_request_context():
-        app.preprocess_request()
         resp = send_file_inline(data_file("example-balances.csv"))
         assert (
             resp.headers["Content-Disposition"]
